@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 __author__ = '陈章'
 __date__ = '2019-04-25 11:34'
+import logging
 import os
 import pickle
 from datetime import datetime
 from functools import wraps
 from urllib.parse import quote_plus
 
-from logzero import logger
+logger = logging.getLogger("python_common_tools")
 
 from python_common_tools.compress import get_md5
 
@@ -22,9 +23,9 @@ class Cache:
                 # prepare cache_file
                 fname = f.__qualname__
                 argv_str = cls.get_argv_str(args, kwargs, is_method)
-                cache_dir_real = f'{cache_dir}/{fname}'
+                cache_dir_real = '{cache_dir}/{fname}'.format(cache_dir=cache_dir, fname=fname)
                 os.makedirs(cache_dir_real, exist_ok=True)
-                cache_file = f'{cache_dir_real}/{get_md5(argv_str)}.pkl'
+                cache_file = '{cache_dir_real}/{name}.pkl'.format(cache_dir_real=cache_dir_real, name=get_md5(argv_str))
                 r = cls.exec_func(cache_file, fname, f, args, kwargs)
                 return r
 
@@ -35,15 +36,15 @@ class Cache:
     @classmethod
     def get_argv_str(cls, args, kwargs, is_method=False):
         if is_method:
-            return f'{quote_plus(str(args[1:]))}_{quote_plus(str(kwargs))}'
+            return '{arg}_{kwa}'.format(arg=quote_plus(str(args[1:])), kwa=quote_plus(str(kwargs)))
         else:
-            return f'{quote_plus(str(args))}_{quote_plus(str(kwargs))}'
+            return '{arg}_{kwa}'.format(arg=quote_plus(str(args)), kwa=quote_plus(str(kwargs)))
 
     @classmethod
     def exec_func(cls, cache_file, fname, f, args, kwargs):
         # exec func
         if not os.path.exists(cache_file):
-            logger.debug(f'exec func {fname} {args} {kwargs}')
+            logger.debug('exec func {fname} {args} {kwargs}'.format(fname=fname, args=args, kwargs=kwargs))
             r = f(*args, **kwargs)
             cls.write_to_cache_file(cache_file, r)
         r = cls.read_from_cache_file(cache_file)
@@ -58,9 +59,9 @@ class Cache:
                 fname = f.__qualname__
                 today = datetime.now().strftime("%Y%m%d")
                 argv_str = cls.get_argv_str(args, kwargs, is_method)
-                cache_dir_real = f'{cache_dir}/{fname}/{today}'
+                cache_dir_real = '{cache_dir}/{fname}/{today}'.format(cache_dir=cache_dir, fname=fname, today=today)
                 os.makedirs(cache_dir_real, exist_ok=True)
-                cache_file = f'{cache_dir_real}/{get_md5(argv_str)}.pkl'
+                cache_file = '{cache_dir_real}/{name}.pkl'.format(cache_dir_real=cache_dir_real, name=get_md5(argv_str))
                 r = cls.exec_func(cache_file, fname, f, args, kwargs)
                 return r
 
